@@ -16,6 +16,7 @@
 #include <Akonadi/CalendarBase>
 #include <Akonadi/CalendarUtils>
 #include <Akonadi/CollectionFetchJob>
+#include <Akonadi/ETMCalendar>
 #include <Akonadi/ItemFetchScope>
 
 #include <KCalUtils/IncidenceFormatter>
@@ -34,15 +35,9 @@ TextBrowser::TextBrowser(QWidget *parent)
     setFrameStyle(QFrame::NoFrame);
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void TextBrowser::setSource(const QUrl &name)
-#else
 void TextBrowser::doSetSource(const QUrl &name, QTextDocument::ResourceType type)
-#endif
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     Q_UNUSED(type);
-#endif
     QString uri = name.toString();
     // QTextBrowser for some reason insists on putting // or / in links,
     // this is a crude workaround
@@ -77,7 +72,7 @@ public:
         QString text;
 
         if (mCurrentItem.isValid()) {
-            text = KCalUtils::IncidenceFormatter::extensiveDisplayStr(Akonadi::CalendarUtils::displayName(mCalendar, mParentCollection),
+            text = KCalUtils::IncidenceFormatter::extensiveDisplayStr(Akonadi::CalendarUtils::displayName(mETM, mParentCollection),
                                                                       Akonadi::CalendarUtils::incidence(mCurrentItem),
                                                                       mDate);
             text.prepend(mHeaderText);
@@ -111,7 +106,7 @@ public:
         mAttachmentHandler->view(attachmentName, Akonadi::CalendarUtils::incidence(mCurrentItem));
     }
 
-    Akonadi::ETMCalendar *mCalendar = nullptr;
+    Akonadi::EntityTreeModel *mETM = nullptr;
     IncidenceViewer *const mParent;
     TextBrowser *mBrowser = nullptr;
     Akonadi::Item mCurrentItem;
@@ -129,7 +124,15 @@ IncidenceViewer::IncidenceViewer(Akonadi::ETMCalendar *calendar, QWidget *parent
     : QWidget(parent)
     , d(new IncidenceViewerPrivate(this))
 {
-    d->mCalendar = calendar;
+    d->mETM = calendar->entityTreeModel();
+    init();
+}
+
+IncidenceViewer::IncidenceViewer(Akonadi::EntityTreeModel *etm, QWidget *parent)
+    : QWidget(parent)
+    , d(new IncidenceViewerPrivate(this))
+{
+    d->mETM = etm;
     init();
 }
 
@@ -137,7 +140,6 @@ IncidenceViewer::IncidenceViewer(QWidget *parent)
     : QWidget(parent)
     , d(new IncidenceViewerPrivate(this))
 {
-    d->mCalendar = nullptr;
     init();
 }
 
@@ -162,7 +164,12 @@ IncidenceViewer::~IncidenceViewer() = default;
 
 void IncidenceViewer::setCalendar(Akonadi::ETMCalendar *calendar)
 {
-    d->mCalendar = calendar;
+    d->mETM = calendar->entityTreeModel();
+}
+
+void IncidenceViewer::setModel(Akonadi::EntityTreeModel *model)
+{
+    d->mETM = model;
 }
 
 Akonadi::Item IncidenceViewer::incidence() const
